Crate frame_buffer_wasmtime

Crate frame_buffer_wasmtime 

This crate is mostly just a shell. It exports HasBuffer and binds it to wasmtime.

The actual implementation lives in the surface-wasmtime crate (see surface_frame_buffer.rs).

Modules

wasi_gfx

Structs

FrameBufferCtx
GfxBuffer
Imports
Auto-generated bindings for an instance a component which implements the world imports.
ImportsIndices
Auto-generated bindings for index of the exports of imports.
ImportsPre
Auto-generated bindings for a pre-instantiated version of a component which implements the world imports.

Traits

FrameBufferCtxView
HasBuffer

Functions

add_to_linker