pub struct Imports {}Expand description
Auto-generated bindings for an instance a component which
implements the world imports.
This structure can be created through a number of means depending on your requirements and what you have on hand:
-
The most convenient way is to use
Imports::instantiatewhich only needs aStore,Component, andLinker. -
Alternatively you can create a
ImportsPreahead of time with aComponentto front-load string lookups of exports once instead of per-instantiation. This method then usesImportsPre::instantiateto create aImports. -
If you’ve instantiated the instance yourself already then you can use
Imports::new.
These methods are all equivalent to one another and move around the tradeoff of what work is performed when.
Implementations
Sourceimpl Imports
impl Imports
Sourcepub fn instantiate<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Imports>
pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Imports>
Convenience wrapper around ImportsPre::new and
ImportsPre::instantiate.
Sourcepub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Imports>
pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Imports>
Convenience wrapper around ImportsIndices::new and
ImportsIndices::load.
Sourcepub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Imports>where
_T: Send,
pub async fn instantiate_async<_T>(
store: impl AsContextMut<Data = _T>,
component: &Component,
linker: &Linker<_T>,
) -> Result<Imports>where
_T: Send,
Convenience wrapper around ImportsPre::new and
ImportsPre::instantiate_async.
pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>